@@ -5,16 +5,17 @@ import ssl
 import time
 
 import requests
-
 from bs4 import BeautifulSoup
 
-from utils import filex, tsv, timex, browser
+from utils import filex, timex, tsv
+from utils.browserx import Browser
 from utils.cache import cache
 
-USER_AGENT = 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10.14; rv:65.0)' \
+USER_AGENT = (
+    'Mozilla/5.0 (Macintosh; Intel Mac OS X 10.14; rv:65.0) '
     + 'Gecko/20100101 Firefox/65.0'
+)
 ENCODING = 'utf-8'
-SELENIUM_SCROLL_SCRIPT = "window.scrollTo(0, document.body.scrollHeight);"
 SELENIUM_SCROLL_REPEATS = 3
 SELENIUM_SCROLL_WAIT_TIME = 0.5
 
@@ -42,12 +43,12 @@ def _read_helper_nocached(url):
 
 
 def _read_helper_selenium(url):
-    _browser = browser.open_browser(url)
+    browser = Browser(url)
     for _ in range(0, SELENIUM_SCROLL_REPEATS):
-        _browser.execute_script(SELENIUM_SCROLL_SCRIPT)
+        browser.scroll_to_bottom()
         time.sleep(SELENIUM_SCROLL_WAIT_TIME)
-    content = _browser.page_source
-    _browser.quit()
+    content = browser.get_source()
+    browser.quit()
     return content
 
 
@@ -91,9 +92,11 @@ def exists(url):
 def get_all_urls(root_url, cached=True):
     """Get all URLs linked to a webpage."""
     soup = BeautifulSoup(read(root_url, cached), 'html.parser')
-    urls = list(map(
-        lambda a_link: a_link['href'],
-        soup.find_all('a', href=True),
-    ))
+    urls = list(
+        map(
+            lambda a_link: a_link['href'],
+            soup.find_all('a', href=True),
+        )
+    )
     logging.debug('Found %d links on %s', len(urls), root_url)
     return urls
